@@ -5,12 +5,12 @@ from typing import Generator, List, Callable, Optional, Union
 
 import numpy as np
 from ocr4all_pixel_classifier.lib.dataset import DatasetLoader, SingleData
-from ocr4all_pixel_classifier.lib.image_map import load_image_map_from_file, DEFAULT_IMAGE_MAP
 from ocr4all_pixel_classifier.lib.image_ops import compute_char_height
 from ocr4all_pixel_classifier.lib.output import output_data, scale_to_original_shape
 from ocr4all_pixel_classifier.lib.postprocess import find_postprocessor, postprocess_help
 from ocr4all_pixel_classifier.lib.predictor import Predictor, PredictSettings, Prediction
-from ocr4all_pixel_classifier.lib.util import glob_all
+from ocr4all.files import glob_all
+from ocr4all.colors import ColorMap, DEFAULT_COLOR_MAPPING
 from tqdm import tqdm
 
 
@@ -48,8 +48,6 @@ def main():
     image_file_paths = sorted(glob_all(args.images))
     binary_file_paths = sorted(glob_all(args.binary))
 
-    norm_file_paths = sorted(glob_all(args.norm)) if args.norm else []
-
     if len(image_file_paths) != len(binary_file_paths):
         parser.error("Got {} images but {} binary images".format(len(image_file_paths), len(binary_file_paths)))
 
@@ -57,10 +55,40 @@ def main():
 
     num_files = len(image_file_paths)
 
+    line_heights = parse_line_heights(args, num_files, parser)
+
+    post_processors = [find_postprocessor(p) for p in args.postprocess]
+    if args.cc_majority:
+        from ocr4all_pixel_classifier.lib.postprocess import vote_connected_component_class
+        post_processors += [vote_connected_component_class]
+
+    os.makedirs(args.output, exist_ok=True)
+
+    if args.color_map:
+        color_map = ColorMap.load(args.color_map)
+    else:
+        color_map = ColorMap(DEFAULT_COLOR_MAPPING)
+
+    predictions = predict(args.output,
+                          binary_file_paths,
+                          image_file_paths,
+                          color_map,
+                          line_heights,
+                          target_line_height=args.target_line_height,
+                          models=args.load,
+                          high_res_output=not args.keep_low_res,
+                          post_processors=post_processors,
+                          gpu_allow_growth=args.gpu_allow_growth,
+                          )
+
+    for _, prediction in tqdm(enumerate(predictions)):
+        output_data(args.output, prediction.labels, prediction.data, color_map)
+
+
+def parse_line_heights(args, num_files, parser):
     if args.char_height:
         line_heights = [args.char_height] * num_files
     elif args.norm:
-        print(f'norm: {args.norm}')
         norm_file_paths = sorted(glob_all(args.norm)) if args.norm else []
         if len(norm_file_paths) == 1:
             line_heights = [json.load(open(norm_file_paths[0]))["char_height"]] * num_files
@@ -72,41 +100,14 @@ def main():
         if not args.binary:
             parser.error("No binary files given, cannot auto-detect char height")
         line_heights = [compute_char_height(image, True)
-                                 for image in tqdm(args.binary, desc="Auto-detecting char height", unit="pages")]
-
-
-    post_processors = [find_postprocessor(p) for p in args.postprocess]
-    if args.cc_majority:
-        from ocr4all_pixel_classifier.lib.postprocess import vote_connected_component_class
-        post_processors += [vote_connected_component_class]
-
-    os.makedirs(args.output, exist_ok=True)
-
-    if args.color_map:
-        image_map = load_image_map_from_file(args.color_map)
-    else:
-        image_map = DEFAULT_IMAGE_MAP
-
-    predictions = predict(args.output,
-                          binary_file_paths,
-                          image_file_paths,
-                          image_map,
-                          line_heights,
-                          target_line_height=args.target_line_height,
-                          models=args.load,
-                          high_res_output=not args.keep_low_res,
-                          post_processors=post_processors,
-                          gpu_allow_growth=args.gpu_allow_growth,
-                          )
-
-    for _, prediction in tqdm(enumerate(predictions)):
-        output_data(args.output, prediction.labels, prediction.data, image_map)
+                        for image in tqdm(args.binary, desc="Auto-detecting char height", unit="pages")]
+    return line_heights
 
 
 def predict(output,
             binary_file_paths: List[str],
             image_file_paths: List[str],
-            color_map: dict,
+            color_map: ColorMap,
             line_heights: Union[List[int], int],
             target_line_height: int,
             models: List[str],
